| Title: | GBIF Dataset Explorer |
|---|---|
| Description: | Functions to explore datasets from the Global Biodiversity Information Facility (GBIF - <https://www.gbif.org/>) using a Shiny interface. |
| Authors: | Luis J Villanueva [aut, cre] |
| Maintainer: | Luis J Villanueva <[email protected]> |
| License: | Apache License (>= 2.0) |
| Version: | 0.2.1 |
| Built: | 2026-05-25 06:53:52 UTC |
| Source: | https://github.com/smithsonian/gbif-dataset-explorer |
launches the GDE app
launchApp()launchApp()
shiny application object
Function that loads the data in a zip file downloaded from GBIF
load_gbif_dwc(zipfile = NA, tmpdir = "tmp", page_title = "GBIF Data")load_gbif_dwc(zipfile = NA, tmpdir = "tmp", page_title = "GBIF Data")
zipfile |
Path to the zipfile |
tmpdir |
Temporary path for extracted files |
page_title |
Title to show on the Shiny app. |
## Not run: data_loaded <- load_gbif_dwc(zipfile = "####.zip", tmpdir = "tmp", page_title = "GBIF Dataset 1") ## End(Not run)## Not run: data_loaded <- load_gbif_dwc(zipfile = "####.zip", tmpdir = "tmp", page_title = "GBIF Dataset 1") ## End(Not run)
Shiny app server function
shinyAppServer(input, output, session)shinyAppServer(input, output, session)
input |
provided by shiny |
output |
provided by shiny |
session |
provided by shiny |
shinyAppServer
shinyAppUIshinyAppUI
An object of class shiny.tag.list (inherits from list) of length 4.